==> modified-shop_1.06-r4642_install.zip: modified-shop_1.06-r4642_install/shoproot/lang/english/modules/order_total/ot_loworderfee.php <==
<?php
/* -----------------------------------------------------------------------------------------
   $Id: ot_loworderfee.php 899 2005-04-29 02:40:57Z hhgag $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   -----------------------------------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(ot_loworderfee.php,v 1.2 2002/04/17); www.oscommerce.com 
   (c) 2003	 nextcommerce (ot_loworderfee.php,v 1.4 2003/08/13); www.nextcommerce.org

   Released under the GNU General Public License 
   ---------------------------------------------------------------------------------------*/

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TITLE', 'Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESCRIPTION', 'Low Order Fee');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_TITLE','Display Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_DESC','Do you want to display the low order fee?');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_TITLE','Sort Order');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_DESC','Sort order of display.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_TITLE','Allow Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_DESC','Do you want to allow low order fees?');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_TITLE','Order Fee For Orders Under');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_DESC','Add the low order fee to orders under this amount.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_TITLE','Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_DESC','Low order fee.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_TITLE','Attach Low Order Fee On Orders Made');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_DESC','Attach low order fee for orders to be sent to the set destination.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_TITLE','Tax Class');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_DESC','Use the following tax class on the low order fee.');
?>

==> modified-shop_2.0.7.2-r14622_install.zip: modified-shop_2.0.7.2-r14622_install/shoproot/lang/english/modules/order_total/ot_loworderfee.php <==
<?php
/* -----------------------------------------------------------------------------------------
   $Id: ot_loworderfee.php 899 2005-04-29 02:40:57Z hhgag $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   -----------------------------------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(ot_loworderfee.php,v 1.2 2002/04/17); www.oscommerce.com 
   (c) 2003	 nextcommerce (ot_loworderfee.php,v 1.4 2003/08/13); www.nextcommerce.org

   Released under the GNU General Public License 
   ---------------------------------------------------------------------------------------*/

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TITLE', 'Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESCRIPTION', 'Low Order Fee');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_TITLE','Display Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS_DESC','Do you want to display the low order fee?');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_TITLE','Sort Order');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER_DESC','Sort order of display.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_TITLE','Allow Low Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE_DESC','Do you want to allow low order fees?');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_TITLE','Order Fee For Orders Under');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_DESC','Add the low order fee to orders under this amount.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_INTERNATIONAL_TITLE','Order Fee for international orders under');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER_INTERNATIONAL_DESC','Add the low order fee to international orders under this amount.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_INTERNATIONAL_TITLE','Order Fee international');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_INTERNATIONAL_DESC','Low order fee international.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_TITLE','Order Fee');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_FEE_DESC','Low order fee.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_TITLE','Attach Low Order Fee On Orders Made');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION_DESC','Attach low order fee for orders to be sent to the set destination.');

  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_TITLE','Tax Class');
  define('MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS_DESC','Use the following tax class on the low order fee.');
?>
